import MySQLdb
import time
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = 'Command For Populating Data into a remote DB'


    def handle(self, *args, **options):
        """

        :param args:
        :param options:
        :return:
        """
        start_time = time.time()
        conn = MySQLdb.connect(host="localhost", user="root", password="kuliza123", db="dump2")
        curr = conn.cursor()
        SQL = 'INSERT INTO database_dump_robochatview VALUES ({},"asas","ab","ab",1212,1212,12121,2121,12)'
        for i in range(100000):
            curr.execute(SQL.format(i+1))
        curr.close()
        conn.commit()
        conn.close()
        print(time.time()-start_time)


# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-07-13 04:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0011_auto_20180712_1039'),
    ]

    operations = [
        migrations.CreateModel(
            name='RoboCollectionFdv',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('TAG', models.CharField(max_length=3, null=True)),
                ('FINANCIER_ID', models.CharField(max_length=50, null=True)),
                ('APPL_ID', models.CharField(max_length=50, null=True)),
                ('CUST_ID', models.CharField(max_length=50, null=True)),
                ('PRINCIPAL_PAID', models.IntegerField(null=True)),
                ('INTEREST_PAID', models.IntegerField(null=True)),
                ('BCC_PAID', models.IntegerField(null=True)),
                ('OTHER_PAID', models.IntegerField(null=True)),
                ('PREPAYPENALTY_PAID', models.IntegerField(null=True)),
                ('PRINCIPAL_DUE', models.IntegerField(null=True)),
                ('INTEREST_DUE', models.IntegerField(null=True)),
                ('BCC_DUE', models.IntegerField(null=True)),
                ('OTHER_DUE', models.IntegerField(null=True)),
                ('PREPAYPENALTY_DUE', models.IntegerField(null=True)),
                ('LPC_PAID', models.IntegerField(null=True)),
                ('LPC_DUE', models.IntegerField(null=True)),
                ('FORMAT', models.CharField(max_length=60, null=True)),
                ('TENTATIVE_FORECLOSURE_AMT', models.IntegerField(null=True)),
                ('PREPAYPENALTY_PERCENT', models.IntegerField(null=True)),
                ('PRINCIPAL_BALANCE', models.IntegerField(null=True)),
                ('INSTALLMENT', models.IntegerField(null=True)),
                ('PREPAYMENT_PENALTY', models.IntegerField(null=True)),
                ('UNBILLED_INSTALLMENT', models.IntegerField(null=True)),
                ('OVERDUE_CHARGES', models.IntegerField(null=True)),
                ('ADVICE_OUTSTANDING_REPAYMENT_FEE', models.IntegerField(null=True)),
                ('TOTAL_RECEIVABLE', models.IntegerField(null=True)),
                ('NET_TOTAL', models.IntegerField(null=True)),
                ('REFUNDS', models.IntegerField(null=True)),
                ('CLOSURE_DATE', models.DateField(null=True)),
                ('ACCRUED_PENAL_INTEREST', models.CharField(max_length=100, null=True)),
            ],
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-06-07 20:53
from __future__ import unicode_literals

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0005_auto_20180605_2040'),
    ]

    operations = [
        migrations.CreateModel(
            name='RoboEitView',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('LOAN_ACCT_NUM', models.CharField(max_length=64)),
                ('ACID', models.CharField(max_length=44)),
                ('ACCRUED_UPTO_DATE_CR', models.DateField()),
                ('ACCRUED_UPTO_DATE_DR', models.DateField()),
                ('LAST_ACCRUAL_RUN_DATE_CR', models.DateField()),
                ('LAST_ACCRUAL_RUN_DATE_DR', models.DateField()),
                ('NRML_ACCRUED_AMOUNT_CR', models.BigIntegerField()),
                ('NRML_ACCRUED_AMOUNT_DR', models.BigIntegerField()),
                ('BOOKED_UPTO_DATE_CR', models.DateField()),
                ('BOOKED_UPTO_DATE_DR', models.DateField()),
                ('LAST_BOOK_RUN_DATE_CR', models.DateField()),
                ('LAST_BOOK_RUN_DATE_DR', models.DateField()),
                ('BOOK_FOR_REV_DATE_CR', models.DateField()),
                ('BOOK_FOR_REV_DATE_DR', models.DateField()),
                ('NRML_BOOKED_AMOUNT_CR', models.BigIntegerField()),
                ('NRML_BOOKED_AMOUNT_DR', models.BigIntegerField()),
                ('INTEREST_CALC_UPTO_DATE_CR', models.DateField()),
                ('INTEREST_CALC_UPTO_DATE_DR', models.DateField()),
                ('NRML_INTEREST_AMOUNT_CR', models.BigIntegerField()),
                ('NRML_INTEREST_AMOUNT_DR', models.BigIntegerField()),
                ('LAST_INTEREST_RUN_DATE_CR', models.DateField()),
                ('LAST_INTEREST_RUN_DATE_DR', models.DateField()),
                ('NEXT_INT_RUN_DATE_DR', models.DateField()),
                ('NRML_INT_SUSPENSE_AMT_DR', models.BigIntegerField()),
                ('PENAL_ACCRUED_AMOUNT_DR', models.BigIntegerField()),
                ('PENAL_BOOKED_AMOUNT_DR', models.BigIntegerField()),
                ('PENAL_INTEREST_AMOUNT_DR', models.BigIntegerField()),
                ('PENAL_INT_SUSPENSE_AMT_DR', models.BigIntegerField()),
                ('ACCOUNT_PEGGED_FLG', models.CharField(max_length=1)),
                ('GAM_CREATION_TIME', models.DateField()),
                ('GAM_LAST_CHANGE_TIME', models.DateField()),
                ('EIT_CREATION_TIME', models.DateField()),
                ('EIT_LAST_CHANGE_TIME', models.DateField()),
            ],
        ),
        migrations.CreateModel(
            name='RoboLrsView',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('LOAN_ACCT_NUM', models.CharField(max_length=64)),
                ('ACID', models.CharField(max_length=44)),
                ('FLOW_ID', models.CharField(max_length=20)),
                ('NUM_OF_FLOWS', models.IntegerField()),
                ('FLOW_AMT', models.BigIntegerField()),
                ('NUM_OF_DMDS', models.IntegerField()),
                ('NEXT_DMD_DATE', models.DateField()),
                ('NEXT_INT_DMD_DATE', models.DateField()),
                ('CURRENT_INT_REC_FLG', models.CharField(max_length=1)),
                ('GAM_CREATION_TIME', models.DateField()),
                ('GAM_LAST_CHANGE_TIME', models.DateField()),
                ('LRS_CREATION_TIME', models.DateField()),
                ('LRS_LAST_CHANGE_TIME', models.DateField()),
            ],
        ),
        migrations.AddField(
            model_name='generalaccount',
            name='GAC_CREATION_TIME',
            field=models.DateField(default=datetime.datetime(2018, 6, 7, 20, 52, 57, 59855)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='generalaccount',
            name='GAC_LAST_CHANGE_TIME',
            field=models.DateField(default=datetime.datetime(2018, 6, 7, 20, 53, 13, 876361)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='generalaccount',
            name='GAM_CREATION_TIME',
            field=models.DateField(default=datetime.datetime(2018, 6, 7, 20, 53, 18, 923843)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='generalaccount',
            name='GAM_LAST_CHANGE_TIME',
            field=models.DateField(default=datetime.datetime(2018, 6, 7, 20, 53, 23, 587761)),
            preserve_default=False,
        ),
    ]



# import os
import json
from django.core.management.base import BaseCommand
from fec_dbsync import utils as fec_dbsync_utils
from fec_dbsync.models import MISReportRequestTracking
from fec_dbsync.constants import MIS_REPORT_METHODS
import logging


logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = 'Command For Generating MIS Report for different sheets.'

    def handle(self, *args, **options):
        """
        :param args:
        :param options:
        :return:
        """
        report_to_runs = MISReportRequestTracking.objects.filter(status=False)
        if report_to_runs:
            for report_obj in report_to_runs:
                logger.info("Report running: " + report_obj.report_request)
                if hasattr(fec_dbsync_utils, MIS_REPORT_METHODS.get(report_obj.report_request)):
                    try:
                        filters = json.loads(report_obj.filters)
                    except:
                        filters = None
                        logger.debug("Filter Error in report: " + report_obj.report_request + " With filters")
                    try:
                        emails = json.loads(report_obj.emails)
                    except:
                        emails = []
                        logger.debug("Emails Error in report: " + report_obj.report_request + " With emails")
                    try:
                        request_timestamp = report_obj.requester + "_{}_" + report_obj.created_at.strftime("%Y-%m-%d_%H:%M:%S")
                    except:
                        request_timestamp = report_obj.requester + "_{}_" + str(report_obj.id)
                    try:
                        mis_report_file= getattr(fec_dbsync_utils, MIS_REPORT_METHODS.get(report_obj.report_request))(request_timestamp, filters)
                        if type(mis_report_file) == str:
                            report_obj.status = 1
                            report_obj.save()
                            # email_response = fec_dbsync_utils.send_mail(mis_report_file, emails)
                            # if email_response.get('error') is None or email_response.get('error') == "":
                            #     report_obj.update(status=True)
                            #     os.remove(mis_report_file)
                            logger.info("Report generated: " + mis_report_file)
                        else:
                            try:
                                logger.debug("Error: " + json.dumps(mis_report_file))
                            except:
                                logger.debug("Something went wrong in sheet: " + report_obj.report_request)
                    except:
                        logger.debug("Something went wrong in sheet: " + report_obj.report_request)

        logger.info("No Report to run")